@@ -19,8 +19,9 @@ def cal_PCC(refData, testData,calSize,mydll):
     """
     """
 
-    refstruct = refData.ctypes.data_as(POINTER(c_double))
-    teststruct = testData.ctypes.data_as(POINTER(c_double))
+    refstruct = np.ascontiguousarray(refData, dtype=c_double).ctypes.data_as(ctypes.POINTER(c_double))
+    teststruct = np.ascontiguousarray(testData, dtype=c_double).ctypes.data_as(ctypes.POINTER(c_double))
+    mydll.Pearson_Correlation.argtypes = [POINTER(c_double),POINTER(c_double),c_long,POINTER(c_double)]
     pcc= c_double(0.0)
     mydll.Pearson_Correlation(refstruct,teststruct,c_long(calSize),byref(pcc))
     return pcc.value
@@ -29,19 +30,19 @@ def cal_PCC(refData, testData,calSize,mydll):
 if __name__ == '__main__':
     ref = r'C:\Users\vcloud_avl\Documents\我的POPO\src.wav'
     test = r'C:\Users\vcloud_avl\Documents\我的POPO\test.wav'
-    from commFunction import  get_data_array
+    from commFunction import  get_data_array_double
     import platform,time
-    newdata,fs,ch = get_data_array(ref)
-    refdata,fs,ch = get_data_array(test)
-    newdata = newdata[:10000].astype(np.double)
-    refdata = refdata[:10000].astype(np.double)
+    newdata,fs,ch = get_data_array_double(ref)
+    refdata,fs,ch = get_data_array_double(test)
+    newdata = newdata[:10000]
+    refdata = refdata[:10000]
     mydll = None
     cur_paltform = platform.platform().split('-')[0]
     if cur_paltform == 'Windows':
         mydll = ctypes.windll.LoadLibrary(sys.prefix + '/pcc.dll')
     if cur_paltform == 'macOS':
         mydll = CDLL(sys.prefix + '/pcc.dylib')
-    mydll.Pearson_Correlation.argtypes = [POINTER(c_double), POINTER(c_double), c_long, POINTER(c_double)]
+    #mydll.Pearson_Correlation.argtypes = [POINTER(c_double), POINTER(c_double), c_long, POINTER(c_double)]
     # newdata = np.arange(0,20000,2)
     # refdata = np.arange(10000,30000,2)
     # print(len(newdata),len(refdata))
@@ -53,11 +54,13 @@ if __name__ == '__main__':
     suma,sumb = 0,0
     for e in range(10000):
         a = time.time()
-        np.corrcoef(refdata, newdata)
+        res = np.corrcoef(refdata, newdata)
+        print(res)
         b = time.time()
         suma += b - a
         c = time.time()
-        cal_PCC(refdata, newdata, 10000, mydll)
+        res = cal_PCC(refdata, newdata, 10000, mydll)
+        print(res)
         d = time.time()
         sumb += d - c
     print(suma/10000)
